@@ -26,8 +26,8 @@ const DefaultERFormat = "svg"
 
 const SchemaFileName = "schema.json"
 
-// DefaultDistance is the default distance between tables that display relations in the ER
-var DefaultDistance = 1
+// DefaultERDistance is the default distance between tables that display relations in the ER
+var DefaultERDistance = 1
 
 // Config is tbls config
 type Config struct {
@@ -41,6 +41,7 @@ type Config struct {
 	ER                     ER                     `yaml:"er,omitempty"`
 	Include                []string               `yaml:"include,omitempty"`
 	Exclude                []string               `yaml:"exclude,omitempty"`
+	Distance               int                    `yaml:"distance,omitempty"`
 	Lint                   Lint                   `yaml:"lint,omitempty"`
 	LintExclude            []string               `yaml:"lintExclude,omitempty"`
 	Relations              []AdditionalRelation   `yaml:"relations,omitempty"`
@@ -163,10 +164,10 @@ func ERFormat(erFormat string) Option {
 	}
 }
 
-// Distance return Option set Config.ER.Distance
+// Distance return Option set Config.Distance
 func Distance(distance int) Option {
 	return func(c *Config) error {
-		c.ER.Distance = &distance
+		c.Distance = distance
 		return nil
 	}
 }
@@ -181,6 +182,26 @@ func BaseUrl(baseUrl string) Option {
 	}
 }
 
+// Include return Option set Config.Include
+func Include(i []string) Option {
+	return func(c *Config) error {
+		if len(i) > 0 {
+			c.Include = i
+		}
+		return nil
+	}
+}
+
+// Exclude return Option set Config.Exclude
+func Exclude(e []string) Option {
+	return func(c *Config) error {
+		if len(e) > 0 {
+			c.Exclude = e
+		}
+		return nil
+	}
+}
+
 // New return Config
 func New() (*Config, error) {
 	c := Config{}
@@ -237,7 +258,7 @@ func (c *Config) setDefault() error {
 	}
 
 	if c.ER.Distance == nil {
-		c.ER.Distance = &DefaultDistance
+		c.ER.Distance = &DefaultERDistance
 	}
 
 	return nil
@@ -371,23 +392,56 @@ func (c *Config) MergeAdditionalData(s *schema.Schema) error {
 
 // FilterTables filter tables from schema.Schema
 func (c *Config) FilterTables(s *schema.Schema) error {
-	ni := s.NormalizeTableNames(c.Include)
-	ne := s.NormalizeTableNames(c.Exclude)
+	i := append(c.Include, s.NormalizeTableNames(c.Include)...)
+	e := append(c.Exclude, s.NormalizeTableNames(c.Exclude)...)
+
+	includes := []*schema.Table{}
+	excludes := []*schema.Table{}
 	for _, t := range s.Tables {
-		if len(c.Include) == 0 || contains(c.Include, t.Name) || contains(ni, t.Name) {
-			if contains(c.Exclude, t.Name) || contains(ne, t.Name) {
-				err := excludeTableFromSchema(t.Name, s)
-				if err != nil {
-					return errors.Wrap(errors.WithStack(err), fmt.Sprintf("failed to filter table '%s'", t.Name))
-				}
+		li, mi := matchLength(i, t.Name)
+		le, me := matchLength(e, t.Name)
+		switch {
+		case len(c.Include) == 0:
+			if me {
+				excludes = append(excludes, t)
+				continue
 			}
-		} else {
-			err := excludeTableFromSchema(t.Name, s)
-			if err != nil {
-				return errors.Wrap(errors.WithStack(err), fmt.Sprintf("failed to filter table '%s'", t.Name))
+			includes = append(includes, t)
+		case mi:
+			if me && li < le {
+				excludes = append(excludes, t)
+				continue
+			}
+			includes = append(includes, t)
+		default:
+			// c.Include > 0 && !mi
+			excludes = append(excludes, t)
+		}
+	}
+
+	collects := []*schema.Table{}
+	for _, t := range includes {
+		ts, _, err := t.CollectTablesAndRelations(c.Distance, true)
+		if err != nil {
+			return err
+		}
+		for _, tt := range ts {
+			if !tt.Contains(includes) {
+				collects = append(collects, tt)
 			}
 		}
 	}
+
+	for _, t := range excludes {
+		if t.Contains(collects) {
+			continue
+		}
+		err := excludeTableFromSchema(t.Name, s)
+		if err != nil {
+			return errors.Wrap(errors.WithStack(err), fmt.Sprintf("failed to filter table '%s'", t.Name))
+		}
+	}
+
 	return nil
 }
 
@@ -589,11 +643,16 @@ func mergeDetectedRelations(s *schema.Schema, strategy *NamingStrategy) {
 	}
 }
 
-func contains(s []string, e string) bool {
+func matchLength(s []string, e string) (int, bool) {
 	for _, v := range s {
 		if wildcard.MatchSimple(v, e) {
-			return true
+			return len(strings.ReplaceAll(v, "*", "")), true
 		}
 	}
-	return false
+	return 0, false
+}
+
+func match(s []string, e string) bool {
+	_, m := matchLength(s, e)
+	return m
 }
